@@ -1,13 +1,15 @@
+# -*- coding: utf-8 -*-
 '''
 .. note::
 
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 
 Parsing and validation utilites for the Spanish standard norm 43 by the
-"Consejo Superior Bancario" (CSB) for storing bank account transactions.
+"Consejo Superior Bancario" (CSB) / "Asociación Española de Banca" (AEB)
+for storing bank account transactions.
 
 (es) Herramientas para leer y validar datos almacenados siguiendo la norma 43
-del Consejo Superior Bancario (CSB).
+del Consejo Superior Bancario (CSB) / Asociación Española de Banca (CSB).
 
 .. seealso::
 
@@ -18,9 +20,11 @@ del Consejo Superior Bancario (CSB).
     - (http://www.tesoreria.com/oldweb/index.php?option=com_content&view=article&id=128:la-norma-43-del-consejo-superior-bancario-csb&catid=59:normativa-nacional-e-internacional&Itemid=90)
 '''
 
-from csb_file import File, ClosingFile, showInfo
-from account import Account, ClosingAccount
-from exchange import Exchange
-from item import Item
-from record import Record
-from transaction import Transaction
+from __future__ import absolute_import
+
+from .csb_file import File, ClosingFile, showInfo
+from .account import Account, ClosingAccount
+from .exchange import Exchange
+from .item import Item
+from .record import Record
+from .transaction import Transaction
