@@ -5,17 +5,31 @@
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
 
-from csb43.utils import check_strict, raiseCsb43Exception, DECIMAL, currencyISO, currencyISOByLetter, isCurrency
-import csb43.utils.messages as msg
-from csb43.i18n import tr as _
-from transaction import Transaction
-from record import Record
+#from __future__ import print_function
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
+from ..utils import (check_strict,
+                     raiseCsb43Exception,
+                     DECIMAL,
+                     currencyISO,
+                     currencyISOByLetter,
+                     isCurrency,
+                     IS_PY3,
+                     m3_next,
+                     m3_is_string)
+from ..utils import messages as msg
+from ..i18n import tr as _
+from .transaction import Transaction
+from .record import Record
 
 import re
+#import sys
 
 _CUR_NUM = re.compile(r'^\d{3}$')
 _CUR_LET = re.compile(r'^[a-zA-Z]{3}$')
 
+
 class Account(Record):
     '''
     A Csb43 account / (es) Cuenta
@@ -29,7 +43,8 @@ class Account(Record):
 
         >>> a = Account()
         >>> str(a)
-        '11                  000000000000000000000000000000                              '
+        '11                  00000000000000000000000000000\
+0                              '
     '''
 
     def __init__(self, record=None, strict=True, decimal=DECIMAL,
@@ -41,10 +56,12 @@ class Account(Record):
         :param strict: treat warnings as exceptions when `True`
         :type strict: :class:`bool`
 
-        :param decimal: number of digits to be considered as the decimal part in money
+        :param decimal: number of digits to be considered as the decimal \
+        part in money
         :type decimal: :class:`int`
 
-        :param yearFirst: switch between YYMMD [`True`] and DDMMYY [`False`] date formats
+        :param yearFirst: switch between YYMMD [`True`] and DDMMYY [`False`] \
+        date formats
         :type yearFirst: :class:`bool`
 
         :raises: :class:`csb43.utils.Csb43Exception`
@@ -97,7 +114,7 @@ class Account(Record):
 
     @staticmethod
     def is_valid(record):
-        return isinstance(record, basestring)\
+        return m3_is_string(record)\
             and (77 <= len(record) <= 80) and (record[0:2] == '11')
 
     # account number
@@ -157,7 +174,8 @@ class Account(Record):
                 elif _CUR_LET.match(val):
                     obj = currencyISOByLetter(val.upper())
                 else:
-                    raiseCsb43Exception(msg.CURRENCY_EXPECTED(val), strict=True)
+                    raiseCsb43Exception(msg.CURRENCY_EXPECTED(val),
+                                        strict=True)
                 if obj:
                     self._set_currency_code(str(obj.numeric))
         except KeyError:
@@ -290,9 +308,10 @@ class Account(Record):
         if isinstance(record, Transaction):
             self.__transactions.append(record)
         else:
-            self.__transactions.append(Transaction(record, self.__strict,
-                                               decimal=self._decimal,
-                                               yearFirst=self._yearFirst))
+            self.__transactions.append(Transaction(record,
+                                                   self.__strict,
+                                                   decimal=self._decimal,
+                                                   yearFirst=self._yearFirst))
 
     def add_item(self, record):
         '''
@@ -301,7 +320,9 @@ class Account(Record):
         :param record: item record
         :type record: :class:`Item` or :class:`basestring`
 
-        :raises: :class:`csb43.utils.Csb43Exception` when the record is impossible to parse, or if the         maximum number of complementary items has been reached
+        :raises: :class:`csb43.utils.Csb43Exception` when the record is \
+        impossible to parse, or if the maximum number of complementary \
+        items has been reached
 
         .. seealso::
 
@@ -311,7 +332,8 @@ class Account(Record):
 
     def get_account_key(self):
         '''
-        :rtype: :class:`int` two-digits checksum for the bank account / (es) digitos de control
+        :rtype: :class:`int` two-digits checksum for the bank account / (es) \
+        digitos de control
         '''
 
         fixDigit = lambda x: 1 if x == 10 else x
@@ -329,7 +351,7 @@ class Account(Record):
 
         return dig1 * 10 + dig2
 
-    def close_account(self, record = None, update = False):
+    def close_account(self, record=None, update=False):
         '''
         Close the current account and generate an abstract object
 
@@ -339,7 +361,8 @@ class Account(Record):
         :param update: update the abstract if already present
         :type record: :class:`bool`
 
-        :raises: :class:`csb43.utils.Csb43Exception` if invalid record of incongruent abstract
+        :raises: :class:`csb43.utils.Csb43Exception` if invalid record or \
+        incongruent abstract
         '''
 
         if (self.__closing is not None) and not update:
@@ -366,13 +389,17 @@ class Account(Record):
 
         closing = None
 
-        if isinstance(record, basestring):
-            closing = ClosingAccount(record, self.__strict, decimal=self._decimal,
-                                    yearFirst=self._yearFirst)
+        if m3_is_string(record):
+            closing = ClosingAccount(record,
+                                     self.__strict,
+                                     decimal=self._decimal,
+                                     yearFirst=self._yearFirst)
         elif isinstance(record, ClosingAccount):
             closing = record
         elif record is not None:
-            raiseCsb43Exception(msg.INCOMPATIBLE_OBJECT(record, "ClosingAccount", "basestring"), True)
+            raiseCsb43Exception(msg.INCOMPATIBLE_OBJECT(record,
+                                                        "ClosingAccount",
+                                                        "basestring"), True)
 
         if closing:
             rBalance = closing.balance
@@ -382,28 +409,33 @@ class Account(Record):
             rNegative = closing.expenseEntries
 
             if not equal_f(balance, rBalance):
-                raiseCsb43Exception(_("balance (%1.2f) mismatch in closing account "
-                                    "record (%1.2f)") %
-                                    (balance, rBalance), self.__strict)
+                raiseCsb43Exception(
+                    _("balance (%1.2f) mismatch in closing account "
+                      "record (%1.2f)") % (balance, rBalance), self.__strict)
             if not equal_f(pBalance, rPBalance):
-                raiseCsb43Exception(_("income amount (%1.2f) mismatch in closing "
-                                    "account record (%1.2f)") %
-                                    (pBalance, rPBalance), self.__strict)
+                raiseCsb43Exception(
+                    _("income amount (%1.2f) mismatch in closing "
+                      "account record (%1.2f)") % (pBalance,
+                                                   rPBalance), self.__strict)
             if not equal_f(nBalance, rNBalance):
-                raiseCsb43Exception(_("expense amount (%1.2f) mismatch in closing "
-                                    "account record (%1.2f)") %
-                                    (nBalance, rNBalance), self.__strict)
+                raiseCsb43Exception(
+                    _("expense amount (%1.2f) mismatch in closing "
+                      "account record (%1.2f)") % (nBalance,
+                                                   rNBalance), self.__strict)
             if posRecords != rPositive:
-                raiseCsb43Exception(_("income entries (%d) mismatch in closing "
-                                    "account record (%d)") %
-                                    (posRecords, rPositive), self.__strict)
+                raiseCsb43Exception(
+                    _("income entries (%d) mismatch in closing "
+                      "account record (%d)") % (posRecords,
+                                                rPositive), self.__strict)
             if negRecords != rNegative:
-                raiseCsb43Exception(_("expense entries (%d) mismatch in closing "
-                                    "account record (%d)") %
-                                    (negRecords, rNegative), self.__strict)
+                raiseCsb43Exception(
+                    _("expense entries (%d) mismatch in closing "
+                      "account record (%d)") % (negRecords,
+                                                rNegative), self.__strict)
         else:
-            closing = ClosingAccount(strict=self.__strict, decimal=self._decimal,
-                                    yearFirst=self._yearFirst)
+            closing = ClosingAccount(strict=self.__strict,
+                                     decimal=self._decimal,
+                                     yearFirst=self._yearFirst)
             closing.balance = balance
             closing.income = pBalance
             closing.expense = -nBalance
@@ -422,7 +454,8 @@ class Account(Record):
 
     def is_closed(self):
         '''
-        :rtype: :class:`bool` `True`  if this :class:`Account` has been properly closed
+        :rtype: :class:`bool` `True`  if this :class:`Account` has been \
+        properly closed
         '''
         return self.__closing is not None
 
@@ -450,12 +483,13 @@ class Account(Record):
 
     # **** Properties ****
     transactions = property(_get_transactions, None, None,
-                            ":class:`list` of transactions / (es) lista de movimientos")
+                            ":class:`list` of transactions /"
+                            " (es) lista de movimientos")
     initialDate = property(_get_external_initial_date,
                            _set_external_initial_date, None,
                            "Start date of the period to which the information "
-                           "corresponds / (es) fecha de comienzo del periodo al que "
-                           "corresponde la informacion"
+                           "corresponds / (es) fecha de comienzo "
+                           "del periodo al que corresponde la informacion"
                            """
 
 :rtype: :class:`datetime.datetime`
@@ -489,8 +523,8 @@ Setting a date::
                               "(es) montante del balance inicial"
                               """
 
-Quantities can be assigned as numbers or strings, and they will be truncated to adjust the
-decimal format set for the object::
+Quantities can be assigned as numbers or strings, and they will be truncated
+to adjust the decimal format set for the object::
 
     >>> a.initialBalance = 123
     >>> a.initialBalance
@@ -570,10 +604,11 @@ decimal format set for the object::
     abstract = property(_get_closing, None, None,
                         ":rtype: :class:`ClosingAccount` account abstract")
 
-    informationMode = property(_get_external_information_mode, _set_external_information_mode, None,
-                        "information mode / "
-                        "(es) modalidad de informacion"
-                        """
+    informationMode = property(_get_external_information_mode,
+                               _set_external_information_mode, None,
+                               "information mode / "
+                               "(es) modalidad de informacion"
+                               """
 
 >>> a.informationMode = 1
 >>> a.informationMode
@@ -585,14 +620,18 @@ decimal format set for the object::
 
     def as_dict(self):
         '''
-        :rtype: a representation of this object as a :class:`dict`. The keys will be localised
+        :rtype: a representation of this object as a :class:`dict`. The keys \
+        will be localised
         '''
 
         d = {
-            msg.T_INITIAL_DATE: str(self.initialDate.date()) if self.initialDate else None,
-            msg.T_FINAL_DATE: str(self.finalDate.date()) if self.finalDate else None,
+            msg.T_INITIAL_DATE: (str(self.initialDate.date())
+                                 if self.initialDate else None),
+            msg.T_FINAL_DATE: (str(self.finalDate.date())
+                               if self.finalDate else None),
             msg.T_INITIAL_BALANCE: self.initialBalance,
-            msg.T_CURRENCY: str(self.currency.letter) if self.currency else None,
+            msg.T_CURRENCY: (str(self.currency.letter)
+                             if self.currency else None),
             msg.T_SHORT_NAME: self.shortName,
             msg.T_ACCOUNT_NUMBER: self.accountNumber,
             msg.T_BANK_CODE: self.bankCode,
@@ -612,26 +651,31 @@ decimal format set for the object::
         return d
 
     def __main_str(self):
-        return "11{b_code: >4}{of_code: >4}{ac_num: >10}{in_date:0>6}{fin_date:0>6}{e_i:0>1}{bal:0>14}{cur:0>3}{info: >1}{nom: <26}{padding: <3}".format(
-                b_code = self._get_bank_code() or '',
-                of_code = self._get_office_code() or '',
-                ac_num = self._get_account_number() or '',
-                in_date = self._get_initial_date() or '',
-                fin_date = self._get_final_date() or '',
-                e_i = self._get_expense_or_income() or '',
-                bal = self._get_initial_balance() or '',
-                cur = self._get_currency_code() or '',
-                info = self._get_information_mode() or '',
-                nom = self._get_short_name() or '',
-                padding = self._get_padding() or ''
-            )
+        return ("11"
+                "{b_code: >4}{of_code: >4}{ac_num: >10}{in_date:0>6}"
+                "{fin_date:0>6}{e_i:0>1}{bal:0>14}{cur:0>3}{info: >1}"
+                "{nom: <26}{padding: <3}".format(
+                    b_code=self._get_bank_code() or '',
+                    of_code=self._get_office_code() or '',
+                    ac_num=self._get_account_number() or '',
+                    in_date=self._get_initial_date() or '',
+                    fin_date=self._get_final_date() or '',
+                    e_i=self._get_expense_or_income() or '',
+                    bal=self._get_initial_balance() or '',
+                    cur=self._get_currency_code() or '',
+                    info=self._get_information_mode() or '',
+                    nom=self._get_short_name() or '',
+                    padding=self._get_padding() or ''
+                ))
 
     def __iter__(self):
-        ''':rtype: iterator of all the `CSB43` records that this object represents'''
+        ''':rtype: iterator of all the `CSB43` records that this object \
+        represents'''
         return _AccountIter(self, self.__main_str())
 
     def __str__(self):
-        r''':rtype: representation of this object as `CSB43` records (using `\\n` as separator)'''
+        ''':rtype: representation of this object as `CSB43` records (using \
+        `\\\\n` as separator)'''
         return '\n'.join([x for x in self])
 
 
@@ -647,12 +691,13 @@ class _AccountIter(object):
         self.__tran = None
 
     def next(self):
+
         if self.__tran:
             try:
-                return self.__tran.next()
+                return m3_next(self.__tran)
             except StopIteration:
                 self.__tran = None
-        now = self.__iter.next()
+        now = m3_next(self.__iter)
 
         if isinstance(now, Transaction):
             self.__tran = iter(now)
@@ -660,6 +705,10 @@ class _AccountIter(object):
         else:
             return str(now)
 
+    if IS_PY3:
+        def __next__(self):
+            return self.next()
+
 
 class ClosingAccount(Record):
     '''
@@ -675,10 +724,12 @@ class ClosingAccount(Record):
         :param strict: treat warnings as exceptions when `True`
         :type strict: :class:`bool`
 
-        :param decimal: number of digits to be considered as the decimal part in money
+        :param decimal: number of digits to be considered as the decimal part \
+        in money
         :type decimal: :class:`int`
 
-        :param yearFirst: switch between YYMMD [`True`] and DDMMYY [`False`] date formats
+        :param yearFirst: switch between YYMMD [`True`] and DDMMYY [`False`] \
+        date formats
         :type yearFirst: :class:`bool`
 
         :raises: :class:`csb43.utils.Csb43Exception`
@@ -845,7 +896,8 @@ class ClosingAccount(Record):
                 elif _CUR_LET.match(val):
                     obj = currencyISOByLetter(val.upper())
                 else:
-                    raiseCsb43Exception(msg.CURRENCY_EXPECTED(val), strict=True)
+                    raiseCsb43Exception(msg.CURRENCY_EXPECTED(val),
+                                        strict=True)
                 if obj:
                     self._set_currency_code(str(obj.numeric))
         except KeyError:
@@ -857,7 +909,7 @@ class ClosingAccount(Record):
 
     @staticmethod
     def is_valid(record):
-        return isinstance(record, basestring) and\
+        return m3_is_string(record) and\
             (76 <= len(record) <= 80) and (record[0:2] == '33')
 
     # account number
@@ -887,21 +939,23 @@ class ClosingAccount(Record):
     def _set_office_code(self, value, strict=True):
         self.__officeCode = value
 
-
     def __str__(self):
-        return "33{bank_code: >4}{of_code: >4}{ac_number: >10}{ex_num:0>5}{ex_am:0>14}{in_num:0>5}{in_am:0>14}{bal_code:0>1}{bal:0>14}{cur:0>3}{padding: >4}".format(
-                bank_code = self._get_bank_code() or '',
-                of_code = self._get_office_code() or '',
-                ac_number = self._get_account_number() or '',
-                ex_num = self._get_expense_entries() or '',
-                ex_am = self._get_expense_amount() or '',
-                in_num = self._get_income_entries() or '',
-                in_am = self._get_income_amount() or '',
-                bal_code = self._get_total_balance_code() or '',
-                bal = self._get_total_balance() or '',
-                cur = self._get_currency_code() or '',
-                padding = self._get_padding() or ''
-            )
+        return ("33"
+                "{bank_code: >4}{of_code: >4}{ac_number: >10}{ex_num:0>5}"
+                "{ex_am:0>14}{in_num:0>5}{in_am:0>14}{bal_code:0>1}{bal:0>14}"
+                "{cur:0>3}{padding: >4}".format(
+                    bank_code=self._get_bank_code() or '',
+                    of_code=self._get_office_code() or '',
+                    ac_number=self._get_account_number() or '',
+                    ex_num=self._get_expense_entries() or '',
+                    ex_am=self._get_expense_amount() or '',
+                    in_num=self._get_income_entries() or '',
+                    in_am=self._get_income_amount() or '',
+                    bal_code=self._get_total_balance_code() or '',
+                    bal=self._get_total_balance() or '',
+                    cur=self._get_currency_code() or '',
+                    padding=self._get_padding() or ''
+                ))
 
     def as_dict(self):
         return {
@@ -918,23 +972,29 @@ class ClosingAccount(Record):
     bankCode = property(_get_bank_code, _set_bank_code, None,
                         """bank code / (es) codigo de banco""")
     branchCode = property(_get_office_code, _set_office_code, None,
-                          """branch code / (es) codigo de sucursal u oficina""")
+                          """branch code / (es) codigo de sucursal u \
+oficina""")
     expenseEntries = property(_get_external_expense_entries,
                               _set_external_expense_entries, None,
-                              """number of debit entries / (es) numero de entradas en el debe""")
+                              """number of debit entries / (es) numero de \
+entradas en el debe""")
     expense = property(_get_external_expense_amount,
                        _set_external_expense_amount, None,
-                       """total debit amounts / (es) montante total en el debe""")
+                       """total debit amounts / (es) montante total en el \
+debe""")
     incomeEntries = property(_get_external_income_entries,
                              _set_external_income_entries, None,
-                             """number of credit entries / (es) numero de entradas en el haber""")
+                             """number of credit entries / (es) numero de \
+entradas en el haber""")
     income = property(_get_external_income_amount,
                       _set_external_income_amount, None,
-                      """total credit amounts / (es) montante total en el haber""")
+                      """total credit amounts / (es) montante total en el \
+haber""")
     balance = property(_get_external_total_balance,
                        _set_external_total_balance, None,
                        """final balance / (es) balance final""")
     currency = property(_get_external_currency_code,
                         _set_external_currency_code, None,
-                        """currency object (:class:`pycountry.db.Currency`) / (es) objecto de divisa""")
+                        """currency object (:class:`pycountry.db.Currency`) /\
+(es) objecto de divisa""")
     padding = property(_get_padding, _set_padding, None, "padding")
