@@ -2,11 +2,14 @@
 '''
 @license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
+from __future__ import absolute_import
+from __future__ import unicode_literals
 
 import datetime as date
+import datetime
 
-from csb43.utils import check_strict, raiseCsb43Exception
-from csb43.i18n import tr as _
+from ..utils import check_strict, raiseCsb43Exception
+from ..i18n import tr as _
 
 '''
 0. tarjeta de credito
@@ -101,7 +104,7 @@ class Transaction(object):
         return self.__category
 
     def _set_date(self, value):
-        import datetime
+        #import datetime
         if not isinstance(value, datetime.date):
             raiseCsb43Exception(_("datetime.date expected"), strict=True)
         self.__date = value
@@ -133,7 +136,8 @@ class Transaction(object):
 
     def __str__(self):
         '''
-        :rtype: :class:`str` representation of this record as a row of a Homebank CSV file
+        :rtype: :class:`str` representation of this record as a row of a \
+        Homebank CSV file
         '''
         f = lambda x: '' if x is None else str(x)
         if self.__date is not None:
@@ -151,12 +155,14 @@ class Transaction(object):
 
         return ";".join(l)
 
-    date = property(_get_date, _set_date, None, "date of transaction (:class:`datetime.datetime`)")
+    date = property(_get_date, _set_date, None,
+                    "date of transaction (:class:`datetime.datetime`)")
     mode = property(_get_mode, _set_mode, None, "mode of transaction")
     info = property(_get_info, _set_info, None, "transaction's info")
     payee = property(_get_payee, _set_payee, None, "payee of the transaction")
     description = property(_get_description, _set_description, None,
                            "description of the transaction")
-    amount = property(_get_amount, _set_amount, None, "amount of the transaction")
+    amount = property(_get_amount, _set_amount, None,
+                      "amount of the transaction")
     category = property(_get_category, _set_category, None,
                         "transaction category, according to HomeBank")
