@@ -15,6 +15,7 @@ only transaction response is (partially) implemented.
 
     - (http://www.ofx.net/)
 '''
+from __future__ import absolute_import
 
-from ofx_file import *
-from converter import convertFromCsb, PAYMODES
\ No newline at end of file
+from .ofx_file import *
+from .converter import convertFromCsb, PAYMODES
