@@ -6,6 +6,9 @@ is the conversion from CSB43 (norma 43 del Consejo Superior Bancario). That is,
 only transaction response is (partially) implemented.
 '''
 
+from __future__ import unicode_literals
+#from __future__ import absolute_import
+
 
 DATEFORMAT = "%Y%m%d"  # short date OFX format
 
@@ -123,7 +126,8 @@ class File(OfxObject):
     >>> print f
     <?xml version="1.0" encoding="ASCII"?>
     <?OFX OFXHEADER="200" VERSION="211" SECURITY="NONE"
-    OLDFILEUID="NONE" NEWFILEUID="NONE"?><OFX><BANKMSGSRSV1></BANKMSGSRSV1></OFX>
+    OLDFILEUID="NONE" NEWFILEUID="NONE"?>
+    <OFX><BANKMSGSRSV1></BANKMSGSRSV1></OFX>
     '''
 
     def __init__(self, tagName="ofx"):
@@ -199,7 +203,8 @@ class Response(OfxObject):
 
     def get_currency(self):
         '''
-        :rtype: :class:`pycountry.dbCurrency` -- Default currency for the statement
+        :rtype: :class:`pycountry.dbCurrency` -- \
+        Default currency for the statement
         '''
         return self.__currency
 
@@ -211,7 +216,8 @@ class Response(OfxObject):
 
     def get_transaction_list(self):
         '''
-        :rtype: :class:`TransactionList` -- Statement-transaction-data aggregate
+        :rtype: :class:`TransactionList` -- \
+        Statement-transaction-data aggregate
         '''
         return self.__transactionList
 
@@ -433,7 +439,8 @@ class Transaction(OfxObject):
 
     def get_extended_name(self):
         '''
-        :rtype: :class:`str` -- extended name of payee or description of transaction
+        :rtype: :class:`str` -- extended name of payee or description of \
+        transaction
         '''
         return self.__extendedName
 
@@ -451,19 +458,22 @@ class Transaction(OfxObject):
 
     def get_ref_num(self):
         '''
-        :rtype: :class:`str` -- reference number that uniquely indentifies the transaction.
+        :rtype: :class:`str` -- reference number that uniquely indentifies \
+        the transaction.
         '''
         return self.__refNum
 
     def set_ref_num(self, value):
         '''
-        :param value: reference number that uniquely indentifies the transaction.
+        :param value: reference number that uniquely indentifies the \
+        transaction.
         '''
         self.__refNum = value
 
     def get_type(self):
         '''
-        :rtype: :class:`str` -- transaction type. See :class:`TYPE`. Default ('OTHER')
+        :rtype: :class:`str` -- transaction type. See :class:`TYPE`. Default \
+        ('OTHER')
         '''
         if self.__type is None:
             return Transaction.TYPE[-1]
@@ -472,7 +482,8 @@ class Transaction(OfxObject):
 
     def get_date_posted(self):
         '''
-        :rtype: :class:`datetime.datetime` -- date transaction was posted to account
+        :rtype: :class:`datetime.datetime` -- date transaction was posted to \
+        account
         '''
         return self.__datePosted
 
@@ -544,7 +555,8 @@ class Transaction(OfxObject):
 
     def get_bank_account_to(self):
         '''
-        :rtype: :class:`BankAccount` -- account the transaction is transferring to
+        :rtype: :class:`BankAccount` -- account the transaction is \
+        transferring to
         '''
         return self.__bankAccountTo
 
@@ -568,13 +580,15 @@ class Transaction(OfxObject):
 
     def get_currency(self):
         '''
-        :rtype: :class:`pycountry.db.Currency` -- currency of the transaction, if different from the one in :class:`BankAccount`
+        :rtype: :class:`pycountry.db.Currency` -- currency of the \
+        transaction, if different from the one in :class:`BankAccount`
         '''
         return self.__currency
 
     def get_origin_currency(self):
         '''
-        :rtype: :class:`pycountry.db.Currency` -- currency of the transaction, if different from the one in :class:`BankAccount`
+        :rtype: :class:`pycountry.db.Currency` -- currency of the \
+        transaction, if different from the one in :class:`BankAccount`
         '''
         return self.__originCurrency
 
@@ -689,7 +703,8 @@ class BankAccount(OfxObject):
 
     def get_type(self):
         '''
-        :rtype: :class:`str` -- type of account. See :class:`TYPE` (default *'SAVINGS'*)
+        :rtype: :class:`str` -- type of account. See :class:`TYPE` (default \
+        *'SAVINGS'*)
         '''
         if self.__type is None:
             return BankAccount.TYPE[1]
@@ -843,4 +858,3 @@ class Balance(OfxObject):
                                                         self.__amount),
                                        date=getXMLTag("datasof",
                                                       strDate(self.__date)))
-
