@@ -1,9 +1,14 @@
 
+from __future__ import print_function
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
 import unittest
 import pycountry
 
-from csb43.csb43 import Exchange
-from csb43.utils import utils
+from ..csb43 import Exchange
+from ..utils import utils
+
 
 class TestCsbExchange(unittest.TestCase):
 
@@ -21,15 +26,15 @@ class TestCsbExchange(unittest.TestCase):
             Exchange(record)
 
     def test_init_bad_code(self):
-        record = '2501' + ('1'*76)
+        record = '2501' + ('1' * 76)
 
         with self.assertRaises(utils.Csb43Exception):
             Exchange(record)
 
     def test_init_record(self):
         record = '2401'
-        record += '840' # currency code
-        record += '14'*7 # amount
+        record += '840'  # currency code
+        record += '14' * 7  # amount
         record += '1' * 59
 
         try:
@@ -56,7 +61,7 @@ class TestCsbExchange(unittest.TestCase):
         self.assertIsNotNone(self.exch.sourceCurrency)
         self.assertEqual('EUR', self.exch.sourceCurrency.letter)
 
-        self.exch.sourceCurrency = 'usd' # 840
+        self.exch.sourceCurrency = 'usd'  # 840
 
         self.assertIsNotNone(self.exch.sourceCurrency)
         self.assertEqual('840', self.exch.sourceCurrency.numeric)
@@ -75,7 +80,7 @@ class TestCsbExchange(unittest.TestCase):
 
         self.assertIsNone(self.exch.amount)
 
-        value = '12345'*4
+        value = '12345' * 4
 
         with self.assertRaises(utils.Csb43Exception):
             self.exch.amount = value
@@ -100,7 +105,6 @@ class TestCsbExchange(unittest.TestCase):
         with self.assertRaises(ValueError):
             self.exch.amount = value
 
-
     def test_padding(self):
 
         self.assertIsNone(self.exch.padding)
@@ -110,7 +114,7 @@ class TestCsbExchange(unittest.TestCase):
         with self.assertRaises(utils.Csb43Exception):
             self.exch.padding = value
 
-        value = "0"*9 + (" a c " * 10)
+        value = "0" * 9 + (" a c " * 10)
 
         self.exch.padding = value
 
@@ -124,7 +128,7 @@ class TestCsbExchange(unittest.TestCase):
 
         self.assertEqual('2401', s[0:4])
 
-    def test_str2(self, exch = None):
+    def test_str2(self, exch=None):
 
         exch = exch or self.exch
 
@@ -150,5 +154,3 @@ class TestCsbExchange(unittest.TestCase):
         self.assertEqual(1, len(r))
 
         self.assertEqual(str(self.exch), r[0])
-
-
