@@ -1,9 +1,13 @@
 
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
 import unittest
 import pycountry
 import datetime
 
-from csb43 import ofx
+from .. import ofx
+
 
 class TestOfxGlobal(unittest.TestCase):
 
@@ -73,6 +77,7 @@ class TestOfxGlobal(unittest.TestCase):
         with self.assertRaises(Exception):
             ofx.strCurrency(value)
 
+
 class TestOfxObject(unittest.TestCase):
 
     def test_init(self):
