@@ -3,5 +3,7 @@
 
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
+from __future__ import absolute_import
 
-from utils import *
\ No newline at end of file
+#from utils import *
+from .utils import *
